# Standard Units

```@contents
Pages = ["unitsystems.md","constants.md","convert.md"]
Depth = 1
```
```@contents
Pages = ["units.md"]
Depth = 3
```

[![DOI](https://zenodo.org/badge/317419353.svg)](https://zenodo.org/badge/latestdoi/317419353)

Similar to how SI defines standardized units of `kilogram`, `meter`, `second`, `kelvin`, `coulomb`, `candela`, and `mole`; the following is a comprehensive selection of generated standardized physics units defined by `UnitSystem` defaults useful for scientists and engineers.

## Prefix Units

```@docs
centi
kilo
byte
```

## Mechanics Units

### Angle Units

```@docs
radian
steradian
degree
gradian
arcminute
arcsecond
turn
spat
```

### Time Units

```@docs
second
minute
hour
day
year
```

### Length Units

```@docs
angstrom
inch
foot
surveyfoot
yard
meter
earthmeter
mile
statutemile
meridianmile
admiraltymile
nauticalmile
lunardistance
astronomicalunit
lightyear
parsec
```

### Area Units

```@docs
barn
hectare
acre
surveyacre
```

### Volume Units

```@docs
liter
gallon
quart
pint
cup
fluidounce
teaspoon
tablespoon
```

### Mass Units

```@docs
gram
earthgram
kilogram
tonne
ton
pound
ounce
grain
slug
slinch
hyl
```

### Force Units

```@docs
dyne
newton
poundal
poundforce
kilopond
```

### Pressure Units

```@docs
psi
pascal
barye
bar
technicalatmosphere
atmosphere
inchmercury
torr
```

### Energy Units

```@docs
erg
joule
footpound
calorie
kilocalorie
meancalorie
earthcalorie
thermalunit
gasgallon
tontnt
electronvolt
```

### Power Units

```@docs
watt
horsepowerwatt
horsepowermetric
horsepower
electricalhorsepower
tonsrefrigeration
boilerhorsepower
```

## Electromagnetic Units

### Charge Units
```@docs
coulomb
earthcoulomb
abcoulomb
statcoulomb
```

### Current Units
```@docs
ampere
abampere
statampere
```

### Electromotive Units
```@docs
volt
abvolt
statvolt
```

### Inductance Units
```@docs
henry
abhenry
stathenry
```

### Resistance Units
```@docs
ohm
abohm
statohm
```

### Conductance Units
```@docs
siemens
abmho
statmho
```

### Capacitance Units
```@docs
farad
abfarad
statfarad
```

### Magnetic Flux Units
```@docs
weber
maxwell
statweber
```

### Magnetic Flux Density Units
```@docs
tesla
gauss
stattesla
```

### Magnetic Specialized Units
```@docs
oersted
gilbert
```

## Thermodynamic Units

```@docs
kelvin
rankine
sealevel
mole
earthmole
poundmole
slugmole
slinchmole
katal
amagat
```

## Photometric Units

```@docs
lumen
candela
lux
phot
footcandle
nit
apostilb
stilb
lambert
footlambert
bril
```

## Specialized Units

```@docs
neper
bel
decibel
hertz
rpm
kayser
diopter
bubnoff
gforce
galileo
eotvos
darcy
poise
reyn
stokes
rayl
mpge
langley
jansky
solarflux
curie
sievert
roentgen
```

## Units Index

```@index
Pages = ["units.md","unitsystems.md"]
```

